@@ -4,8 +4,8 @@
 
 ;; Author: Le Wang <lewang.dev.26@gmail.com>
 ;; URL: https://github.com/lewang/spatial-window
-;; Package-Version: 20260215.304
-;; Package-Revision: d194ae2864c3
+;; Package-Version: 20260221.1439
+;; Package-Revision: 2a6a4cec766a
 ;; Package-Requires: ((emacs "28.1") (posframe "1.0.0"))
 ;; Keywords: convenience, windows
 
@@ -482,6 +482,23 @@ Evicts oldest entry when `spatial-window-history-max' is exceeded."
     (when (spatial-window--state-overlays-visible st)
       (spatial-window--show-overlays (spatial-window--state-highlighted-windows st)))))
 
+(defun spatial-window--split-window (win side)
+  "Focus WIN full-frame, then split along SIDE with next buffer.
+SIDE is passed to `split-window' (e.g. \\='right or \\='below).
+WIN becomes the primary (left/top) pane; the new pane receives the
+next buffer from the frame's buffer list."
+  (select-window win)
+  (let ((ignore-window-parameters t))
+    (delete-other-windows win))
+  ;; After delete-other-windows the window is no longer a side window,
+  ;; but clear the parameter explicitly in case it lingers.
+  (set-window-parameter win 'window-side nil)
+  (let ((new-win (split-window win nil side))
+        (next-buf (cl-find-if-not #'minibufferp (cdr (buffer-list (selected-frame))))))
+    (when next-buf
+      (set-window-buffer new-win next-buf)))
+  (message "Split %s" (if (eq side 'right) "side-by-side" "top-bottom")))
+
 (defun spatial-window--complete-single-input (win)
   "Exit selection mode and complete current single-input action on WIN."
   (spatial-window--exit-selection-mode)
@@ -498,6 +515,12 @@ Evicts oldest entry when `spatial-window-history-max' is exceeded."
      (let ((ignore-window-parameters t))
        (delete-other-windows win))
      (message "Focused window"))
+    ('split-right
+     (spatial-window--save-layout 'split-right)
+     (spatial-window--split-window win 'right))
+    ('split-below
+     (spatial-window--save-layout 'split-below)
+     (spatial-window--split-window win 'below))
     (_ (select-window win))))
 
 (defun spatial-window--set-action (action message)
@@ -573,6 +596,16 @@ different window, avoiding an extra deselect step."
   (interactive)
   (spatial-window--set-action 'focus "FOCUS: select window, RET to focus current"))
 
+(defun spatial-window--set-action-split-right ()
+  "Switch to split-right action with current window highlighted."
+  (interactive)
+  (spatial-window--set-action 'split-right "SPLIT |: select window to split side-by-side"))
+
+(defun spatial-window--set-action-split-below ()
+  "Switch to split-below action with current window highlighted."
+  (interactive)
+  (spatial-window--set-action 'split-below "SPLIT -: select window to split top-bottom"))
+
 (defun spatial-window--history-refresh ()
   "Recompute assignments and refresh overlays after history navigation.
 Update highlighted window to match `selected-window' from the
@@ -658,7 +691,7 @@ While browsing: shows available directions and position."
 
 (defun spatial-window--unified-mode-message ()
   "Return hint message for unified selection mode."
-  (format "Select window or: [K]ill [S]wap [F]ocus [RET]done%s"
+  (format "Select window or: [K]ill [S]wap [F]ocus [|]split-h [-]split-v [RET]done%s"
           (spatial-window--history-message-part)))
 
 (defun spatial-window--make-unified-keymap ()
@@ -670,6 +703,8 @@ While browsing: shows available directions and position."
     (define-key map (kbd "K") #'spatial-window--set-action-kill)
     (define-key map (kbd "S") #'spatial-window--set-action-swap)
     (define-key map (kbd "F") #'spatial-window--set-action-focus)
+    (define-key map (kbd "|") #'spatial-window--set-action-split-right)
+    (define-key map (kbd "-") #'spatial-window--set-action-split-below)
     (define-key map (kbd "<left>") #'spatial-window--history-back)
     (define-key map (kbd "<right>") #'spatial-window--history-forward)
     map))
@@ -688,6 +723,11 @@ where you are.  Uppercase modifiers change the action:
       build a multi-kill set, then RET to delete all.
   S - Swap: swap buffers with current window
   F - Focus: press RET to focus current window, or select another
+  | - Split side-by-side: selected window becomes left pane
+  - - Split top-bottom: selected window becomes top pane
+
+The new pane from a split receives the next buffer from the
+frame's buffer list.
 
 Other keys:
   Left/Right - Browse window configuration history
